**Example 1: 绑定文档到房间**



Input: 

```
tccli lcic BindDocumentToRoom --cli-unfold-argument  \
    --DocumentId dmop89Kq \
    --RoomId 123
```

Output: 
```
{
    "Response": {
        "RequestId": "e574aae1-lp02-4225-a2f8-9032h7199f5f0"
    }
}
```

